@@ -48,6 +48,13 @@ def test_toxml4():
     element = Element("foo", dict(bar="zbr"), "contents")
     assert element.xml == """<foo bar="zbr">contents</foo>"""
 
+def test_toxml5():   ## toxml com tag= v= c=
+    e = Element("foo", {"bar":"zbr"}, "contents")
+    assert e.toxml() == """<foo bar="zbr">contents</foo>"""
+    assert e.toxml(tag="XXX") == """<XXX bar="zbr">contents</XXX>"""
+    assert e.toxml(c="XXX") == """<foo bar="zbr">XXX</foo>"""
+    assert e.toxml(tag="T",v={},c="XXX") == """<T>XXX</T>"""
+
 
 def test_father_is_none():
     element = Element("foo", dict(bar="zbr"), "contents")
